import { MetadataRegistry, TreeContainer } from './types';
import { SourceComponent } from './sourceComponent';
import { MetadataType } from '../common';
/**
 * Resolver for metadata type and component objects.
 */
export declare class RegistryAccess {
    readonly registry: MetadataRegistry;
    private forceIgnore;
    private sourceAdapterFactory;
    private tree;
    /**
     * @param registry Custom registry data
     * @param tree `TreeContainer` to traverse with
     */
    constructor(registry?: MetadataRegistry, tree?: TreeContainer);
    getApiVersion(): string;
    /**
     * Get a metadata type definition.
     *
     * @param name Name of the metadata type
     */
    getTypeFromName(name: string): MetadataType;
    /**
     * Get the metadata component(s) from a file path.
     *
     * @param fsPath File path for a piece of metadata
     */
    getComponentsFromPath(fsPath: string): SourceComponent[];
    private getComponentsFromPathRecursive;
    private isMetadata;
    /**
     * Any file with a registered suffix is potentially a content metadata file.
     *
     * @param fsPath File path of a potential content metadata file
     */
    private parseAsContentMetadataXml;
    /**
     * Identify metadata xml for a folder component:
     *    .../email/TestFolder-meta.xml
     *
     * Do not match this pattern:
     *    .../tabs/TestFolder.tab-meta.xml
     */
    private parseAsFolderMetadataXml;
    private resolveComponent;
    private resolveType;
}
