"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
const decomposedSourceAdapter_1 = require("../../../src/metadata-registry/adapters/decomposedSourceAdapter");
const registry_1 = require("../../mock/registry");
const chai_1 = require("chai");
const treeContainers_1 = require("../../../src/metadata-registry/treeContainers");
const metadata_registry_1 = require("../../../src/metadata-registry");
describe('DecomposedSourceAdapter', () => {
    const type = registry_1.mockRegistry.types.reginaking;
    const tree = new treeContainers_1.VirtualTreeContainer(registry_1.regina.REGINA_VIRTUAL_FS);
    const adapter = new decomposedSourceAdapter_1.DecomposedSourceAdapter(type, registry_1.mockRegistry, undefined, tree);
    const expectedComponent = new metadata_registry_1.SourceComponent(registry_1.regina.REGINA_COMPONENT, tree);
    const children = expectedComponent.getChildren();
    it('should return expected SourceComponent when given a root metadata xml path', () => {
        chai_1.expect(adapter.getComponent(registry_1.regina.REGINA_XML_PATH)).to.deep.equal(expectedComponent);
    });
    it('should return expected SourceComponent when given a child xml', () => {
        const expectedChild = children.find((c) => c.xml === registry_1.regina.REGINA_CHILD_XML_PATH_1);
        chai_1.expect(adapter.getComponent(registry_1.regina.REGINA_CHILD_XML_PATH_1)).to.deep.equal(expectedChild);
    });
    it('should return expected SourceComponent when given a child xml in its decomposed folder', () => {
        const expectedChild = children.find((c) => c.xml === registry_1.regina.REGINA_CHILD_XML_PATH_2);
        chai_1.expect(adapter.getComponent(registry_1.regina.REGINA_CHILD_XML_PATH_2)).to.deep.equal(expectedChild);
    });
});
//# sourceMappingURL=decomposedSourceAdapter.js.map